.. _Tracker:

*******
Tracker
*******

The base class of all :term:`trackers` is the class 
:class:`~.Tracker`. 

Inheritance diagram
===================

.. inheritance-diagram:: CGATReport.Tracker
   :parts: 1


cgatreport`Tracker`
=======================

.. automodule:: Tracker
   :members:



